@@ -1,11 +1,9 @@
 package MooseX::Types;
-BEGIN {
-  $MooseX::Types::AUTHORITY = 'cpan:PHAYLON';
-}
-# git description: v0.43-TRIAL-8-g48785ab
-$MooseX::Types::VERSION = '0.44';
+# git description: v0.44-8-g4f7d179
+$MooseX::Types::VERSION = '0.45';
 use Moose;
 # ABSTRACT: Organise your Moose types in libraries
+# KEYWORDS: moose types classes objects constraints declare libraries
 
 use Moose::Util::TypeConstraints;
 use MooseX::Types::TypeDecorator;
@@ -22,322 +20,322 @@ use namespace::autoclean;
 use 5.008;
 my $UndefMsg = q{Action for type '%s' not yet defined in library '%s'};
 
-# =pod
-#
-# =head1 SYNOPSIS
-#
-# =head2 Library Definition
-#
-#   package MyLibrary;
-#
-#   # predeclare our own types
-#   use MooseX::Types -declare => [
-#       qw(
-#           PositiveInt
-#           NegativeInt
-#           ArrayRefOfPositiveInt
-#           ArrayRefOfAtLeastThreeNegativeInts
-#           LotsOfInnerConstraints
-#           StrOrArrayRef
-#           MyDateTime
-#           )
-#   ];
-#
-#   # import builtin types
-#   use MooseX::Types::Moose qw/Int HashRef/;
-#
-#   # type definition.
-#   subtype PositiveInt,
-#       as Int,
-#       where { $_ > 0 },
-#       message { "Int is not larger than 0" };
-#
-#   subtype NegativeInt,
-#       as Int,
-#       where { $_ < 0 },
-#       message { "Int is not smaller than 0" };
-#
-#   # type coercion
-#   coerce PositiveInt,
-#       from Int,
-#           via { 1 };
-#
-#   # with parameterized constraints.
-#
-#   subtype ArrayRefOfPositiveInt,
-#     as ArrayRef[PositiveInt];
-#
-#   subtype ArrayRefOfAtLeastThreeNegativeInts,
-#     as ArrayRef[NegativeInt],
-#     where { scalar(@$_) > 2 };
-#
-#   subtype LotsOfInnerConstraints,
-#     as ArrayRef[ArrayRef[HashRef[Int]]];
-#
-#   # with TypeConstraint Unions
-#
-#   subtype StrOrArrayRef,
-#     as Str|ArrayRef;
-#
-#   # class types
-#
-#   class_type 'DateTime';
-#
-#   # or better
-#
-#   class_type MyDateTime, { class => 'DateTime' };
-#
-#   coerce MyDateTime,
-#     from HashRef,
-#     via { DateTime->new(%$_) };
-#
-#   1;
-#
-# =head2 Usage
-#
-#   package Foo;
-#   use Moose;
-#   use MyLibrary qw( PositiveInt NegativeInt );
-#
-#   # use the exported constants as type names
-#   has 'bar',
-#       isa    => PositiveInt,
-#       is     => 'rw';
-#   has 'baz',
-#       isa    => NegativeInt,
-#       is     => 'rw';
-#
-#   sub quux {
-#       my ($self, $value);
-#
-#       # test the value
-#       print "positive\n" if is_PositiveInt($value);
-#       print "negative\n" if is_NegativeInt($value);
-#
-#       # coerce the value, NegativeInt doesn't have a coercion
-#       # helper, since it didn't define any coercions.
-#       $value = to_PositiveInt($value) or die "Cannot coerce";
-#   }
-#
-#   1;
-#
-# =head1 DESCRIPTION
-#
-# The type system provided by Moose effectively makes all of its builtin type
-# global, as are any types you declare with Moose. This means that every module
-# that declares a type named C<PositiveInt> is sharing the same type object. This
-# can be a problem when different parts of the code base want to use the same
-# name for different things.
-#
-# This package lets you declare types using short names, but behind the scenes
-# it namespaces all your type declarations, effectively prevent name clashes
-# between packages.
-#
-# This is done by creating a type library module like C<MyApp::Types> and then
-# importing types from that module into other modules.
-#
-# As a side effect, the declaration mechanism allows you to write type names as
-# barewords (really function calls), which catches typos in names at compile
-# time rather than run time.
-#
-# This module also provides some helper functions for using Moose types outside
-# of attribute declarations.
-#
-# If you mix string-based names with types created by this module, it will warn,
-# with a few exceptions. If you are declaring a C<class_type()> or
-# C<role_type()> within your type library, or if you use a fully qualified name
-# like C<"MyApp::Foo">.
-#
-# =head1 LIBRARY DEFINITION
-#
-# A MooseX::Types is just a normal Perl module. Unlike Moose
-# itself, it does not install C<use strict> and C<use warnings> in your
-# class by default, so this is up to you.
-#
-# The only thing a library is required to do is
-#
-#   use MooseX::Types -declare => \@types;
-#
-# with C<@types> being a list of types you wish to define in this library.
-# This line will install a proper base class in your package as well as the
-# full set of L<handlers|/"TYPE HANDLER FUNCTIONS"> for your declared
-# types. It will then hand control over to L<Moose::Util::TypeConstraints>'
-# C<import> method to export the functions you will need to declare your
-# types.
-#
-# If you want to use Moose' built-in types (e.g. for subtyping) you will
-# want to
-#
-#   use MooseX::Types::Moose @types;
-#
-# to import the helpers from the shipped L<MooseX::Types::Moose>
-# library which can export all types that come with Moose.
-#
-# You will have to define coercions for your types or your library won't
-# export a L</to_$type> coercion helper for it.
-#
-# Note that you currently cannot define types containing C<::>, since
-# exporting would be a problem.
-#
-# You also don't need to use C<warnings> and C<strict>, since the
-# definition of a library automatically exports those.
-#
-# =head1 LIBRARY USAGE
-#
-# You can import the L<"type helpers"|/"TYPE HANDLER FUNCTIONS"> of a
-# library by C<use>ing it with a list of types to import as arguments. If
-# you want all of them, use the C<:all> tag. For example:
-#
-#   use MyLibrary      ':all';
-#   use MyOtherLibrary qw( TypeA TypeB );
-#
-# MooseX::Types comes with a library of Moose' built-in types called
-# L<MooseX::Types::Moose>.
-#
-# The exporting mechanism is, since version 0.5, implemented via a wrapper
-# around L<Sub::Exporter>. This means you can do something like this:
-#
-#   use MyLibrary TypeA => { -as => 'MyTypeA' },
-#                 TypeB => { -as => 'MyTypeB' };
-#
-# =head1 TYPE HANDLER FUNCTIONS
-#
-# =head2 $type
-#
-# A constant with the name of your type. It contains the type's fully
-# qualified name. Takes no value, as all constants.
-#
-# =head2 is_$type
-#
-# This handler takes a value and tests if it is a valid value for this
-# C<$type>. It will return true or false.
-#
-# =head2 to_$type
-#
-# A handler that will take a value and coerce it into the C<$type>. It will
-# return a false value if the type could not be coerced.
-#
-# B<Important Note>: This handler will only be exported for types that can
-# do type coercion. This has the advantage that a coercion to a type that
-# has not defined any coercions will lead to a compile-time error.
-#
-# =head1 WRAPPING A LIBRARY
-#
-# You can define your own wrapper subclasses to manipulate the behaviour
-# of a set of library exports. Here is an example:
-#
-#   package MyWrapper;
-#   use strict;
-#   use MRO::Compat;
-#   use base 'MooseX::Types::Wrapper';
-#
-#   sub coercion_export_generator {
-#       my $class = shift;
-#       my $code = $class->next::method(@_);
-#       return sub {
-#           my $value = $code->(@_);
-#           warn "Coercion returned undef!"
-#               unless defined $value;
-#           return $value;
-#       };
-#   }
-#
-#   1;
-#
-# This class wraps the coercion generator (e.g., C<to_Int()>) and warns
-# if a coercion returned an undefined value. You can wrap any library
-# with this:
-#
-#   package Foo;
-#   use strict;
-#   use MyWrapper MyLibrary => [qw( Foo Bar )],
-#                 Moose     => [qw( Str Int )];
-#
-#   ...
-#   1;
-#
-# The C<Moose> library name is a special shortcut for L<MooseX::Types::Moose>.
-#
-# =head2 Generator methods you can overload
-#
-# =over 4
-#
-# =item type_export_generator( $short, $full )
-#
-# Creates a closure returning the type's L<Moose::Meta::TypeConstraint> object.
-#
-# =item check_export_generator( $short, $full, $undef_message )
-#
-# This creates the closure used to test if a value is valid for this type.
-#
-# =item coercion_export_generator( $short, $full, $undef_message )
-#
-# This is the closure that's doing coercions.
-#
-# =back
-#
-# =head2 Provided Parameters
-#
-# =over 4
-#
-# =item $short
-#
-# The short, exported name of the type.
-#
-# =item $full
-#
-# The fully qualified name of this type as L<Moose> knows it.
-#
-# =item $undef_message
-#
-# A message that will be thrown when type functionality is used but the
-# type does not yet exist.
-#
-# =back
-#
-# =head1 RECURSIVE SUBTYPES
-#
-# As of version 0.08, L<Moose::Types> has experimental support for Recursive
-# subtypes.  This will allow:
-#
-#     subtype Tree() => as HashRef[Str|Tree];
-#
-# Which validates things like:
-#
-#     {key=>'value'};
-#     {key=>{subkey1=>'value', subkey2=>'value'}}
-#
-# And so on.  This feature is new and there may be lurking bugs so don't be afraid
-# to hunt me down with patches and test cases if you have trouble.
-#
-# =head1 NOTES REGARDING TYPE UNIONS
-#
-# L<MooseX::Types> uses L<MooseX::Types::TypeDecorator> to do some overloading
-# which generally allows you to easily create union types:
-#
-#   subtype StrOrArrayRef,
-#       as Str|ArrayRef;
-#
-# As with parameterized constraints, this overloading extends to modules using the
-# types you define in a type library.
-#
-#   use Moose;
-#   use MooseX::Types::Moose qw(HashRef Int);
-#
-#   has 'attr' => ( isa => HashRef | Int );
-#
-# And everything should just work as you'd think.
-#
-# =head1 METHODS
-#
-# =head2 import
-#
-# Installs the L<MooseX::Types::Base> class into the caller and exports types
-# according to the specification described in L</"LIBRARY DEFINITION">. This
-# will continue to L<Moose::Util::TypeConstraints>' C<import> method to export
-# helper functions you will need to declare your types.
-#
-# =cut
+#pod =pod
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod =head2 Library Definition
+#pod
+#pod   package MyLibrary;
+#pod
+#pod   # predeclare our own types
+#pod   use MooseX::Types -declare => [
+#pod       qw(
+#pod           PositiveInt
+#pod           NegativeInt
+#pod           ArrayRefOfPositiveInt
+#pod           ArrayRefOfAtLeastThreeNegativeInts
+#pod           LotsOfInnerConstraints
+#pod           StrOrArrayRef
+#pod           MyDateTime
+#pod           )
+#pod   ];
+#pod
+#pod   # import builtin types
+#pod   use MooseX::Types::Moose qw/Int HashRef/;
+#pod
+#pod   # type definition.
+#pod   subtype PositiveInt,
+#pod       as Int,
+#pod       where { $_ > 0 },
+#pod       message { "Int is not larger than 0" };
+#pod
+#pod   subtype NegativeInt,
+#pod       as Int,
+#pod       where { $_ < 0 },
+#pod       message { "Int is not smaller than 0" };
+#pod
+#pod   # type coercion
+#pod   coerce PositiveInt,
+#pod       from Int,
+#pod           via { 1 };
+#pod
+#pod   # with parameterized constraints.
+#pod
+#pod   subtype ArrayRefOfPositiveInt,
+#pod     as ArrayRef[PositiveInt];
+#pod
+#pod   subtype ArrayRefOfAtLeastThreeNegativeInts,
+#pod     as ArrayRef[NegativeInt],
+#pod     where { scalar(@$_) > 2 };
+#pod
+#pod   subtype LotsOfInnerConstraints,
+#pod     as ArrayRef[ArrayRef[HashRef[Int]]];
+#pod
+#pod   # with TypeConstraint Unions
+#pod
+#pod   subtype StrOrArrayRef,
+#pod     as Str|ArrayRef;
+#pod
+#pod   # class types
+#pod
+#pod   class_type 'DateTime';
+#pod
+#pod   # or better
+#pod
+#pod   class_type MyDateTime, { class => 'DateTime' };
+#pod
+#pod   coerce MyDateTime,
+#pod     from HashRef,
+#pod     via { DateTime->new(%$_) };
+#pod
+#pod   1;
+#pod
+#pod =head2 Usage
+#pod
+#pod   package Foo;
+#pod   use Moose;
+#pod   use MyLibrary qw( PositiveInt NegativeInt );
+#pod
+#pod   # use the exported constants as type names
+#pod   has 'bar',
+#pod       isa    => PositiveInt,
+#pod       is     => 'rw';
+#pod   has 'baz',
+#pod       isa    => NegativeInt,
+#pod       is     => 'rw';
+#pod
+#pod   sub quux {
+#pod       my ($self, $value);
+#pod
+#pod       # test the value
+#pod       print "positive\n" if is_PositiveInt($value);
+#pod       print "negative\n" if is_NegativeInt($value);
+#pod
+#pod       # coerce the value, NegativeInt doesn't have a coercion
+#pod       # helper, since it didn't define any coercions.
+#pod       $value = to_PositiveInt($value) or die "Cannot coerce";
+#pod   }
+#pod
+#pod   1;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod The type system provided by Moose effectively makes all of its builtin type
+#pod global, as are any types you declare with Moose. This means that every module
+#pod that declares a type named C<PositiveInt> is sharing the same type object. This
+#pod can be a problem when different parts of the code base want to use the same
+#pod name for different things.
+#pod
+#pod This package lets you declare types using short names, but behind the scenes
+#pod it namespaces all your type declarations, effectively prevent name clashes
+#pod between packages.
+#pod
+#pod This is done by creating a type library module like C<MyApp::Types> and then
+#pod importing types from that module into other modules.
+#pod
+#pod As a side effect, the declaration mechanism allows you to write type names as
+#pod barewords (really function calls), which catches typos in names at compile
+#pod time rather than run time.
+#pod
+#pod This module also provides some helper functions for using Moose types outside
+#pod of attribute declarations.
+#pod
+#pod If you mix string-based names with types created by this module, it will warn,
+#pod with a few exceptions. If you are declaring a C<class_type()> or
+#pod C<role_type()> within your type library, or if you use a fully qualified name
+#pod like C<"MyApp::Foo">.
+#pod
+#pod =head1 LIBRARY DEFINITION
+#pod
+#pod A MooseX::Types is just a normal Perl module. Unlike Moose
+#pod itself, it does not install C<use strict> and C<use warnings> in your
+#pod class by default, so this is up to you.
+#pod
+#pod The only thing a library is required to do is
+#pod
+#pod   use MooseX::Types -declare => \@types;
+#pod
+#pod with C<@types> being a list of types you wish to define in this library.
+#pod This line will install a proper base class in your package as well as the
+#pod full set of L<handlers|/"TYPE HANDLER FUNCTIONS"> for your declared
+#pod types. It will then hand control over to L<Moose::Util::TypeConstraints>'
+#pod C<import> method to export the functions you will need to declare your
+#pod types.
+#pod
+#pod If you want to use Moose' built-in types (e.g. for subtyping) you will
+#pod want to
+#pod
+#pod   use MooseX::Types::Moose @types;
+#pod
+#pod to import the helpers from the shipped L<MooseX::Types::Moose>
+#pod library which can export all types that come with Moose.
+#pod
+#pod You will have to define coercions for your types or your library won't
+#pod export a L</to_$type> coercion helper for it.
+#pod
+#pod Note that you currently cannot define types containing C<::>, since
+#pod exporting would be a problem.
+#pod
+#pod You also don't need to use C<warnings> and C<strict>, since the
+#pod definition of a library automatically exports those.
+#pod
+#pod =head1 LIBRARY USAGE
+#pod
+#pod You can import the L<"type helpers"|/"TYPE HANDLER FUNCTIONS"> of a
+#pod library by C<use>ing it with a list of types to import as arguments. If
+#pod you want all of them, use the C<:all> tag. For example:
+#pod
+#pod   use MyLibrary      ':all';
+#pod   use MyOtherLibrary qw( TypeA TypeB );
+#pod
+#pod MooseX::Types comes with a library of Moose' built-in types called
+#pod L<MooseX::Types::Moose>.
+#pod
+#pod The exporting mechanism is, since version 0.5, implemented via a wrapper
+#pod around L<Sub::Exporter>. This means you can do something like this:
+#pod
+#pod   use MyLibrary TypeA => { -as => 'MyTypeA' },
+#pod                 TypeB => { -as => 'MyTypeB' };
+#pod
+#pod =head1 TYPE HANDLER FUNCTIONS
+#pod
+#pod =head2 $type
+#pod
+#pod A constant with the name of your type. It contains the type's fully
+#pod qualified name. Takes no value, as all constants.
+#pod
+#pod =head2 is_$type
+#pod
+#pod This handler takes a value and tests if it is a valid value for this
+#pod C<$type>. It will return true or false.
+#pod
+#pod =head2 to_$type
+#pod
+#pod A handler that will take a value and coerce it into the C<$type>. It will
+#pod return a false value if the type could not be coerced.
+#pod
+#pod B<Important Note>: This handler will only be exported for types that can
+#pod do type coercion. This has the advantage that a coercion to a type that
+#pod has not defined any coercions will lead to a compile-time error.
+#pod
+#pod =head1 WRAPPING A LIBRARY
+#pod
+#pod You can define your own wrapper subclasses to manipulate the behaviour
+#pod of a set of library exports. Here is an example:
+#pod
+#pod   package MyWrapper;
+#pod   use strict;
+#pod   use MRO::Compat;
+#pod   use base 'MooseX::Types::Wrapper';
+#pod
+#pod   sub coercion_export_generator {
+#pod       my $class = shift;
+#pod       my $code = $class->next::method(@_);
+#pod       return sub {
+#pod           my $value = $code->(@_);
+#pod           warn "Coercion returned undef!"
+#pod               unless defined $value;
+#pod           return $value;
+#pod       };
+#pod   }
+#pod
+#pod   1;
+#pod
+#pod This class wraps the coercion generator (e.g., C<to_Int()>) and warns
+#pod if a coercion returned an undefined value. You can wrap any library
+#pod with this:
+#pod
+#pod   package Foo;
+#pod   use strict;
+#pod   use MyWrapper MyLibrary => [qw( Foo Bar )],
+#pod                 Moose     => [qw( Str Int )];
+#pod
+#pod   ...
+#pod   1;
+#pod
+#pod The C<Moose> library name is a special shortcut for L<MooseX::Types::Moose>.
+#pod
+#pod =head2 Generator methods you can overload
+#pod
+#pod =over 4
+#pod
+#pod =item type_export_generator( $short, $full )
+#pod
+#pod Creates a closure returning the type's L<Moose::Meta::TypeConstraint> object.
+#pod
+#pod =item check_export_generator( $short, $full, $undef_message )
+#pod
+#pod This creates the closure used to test if a value is valid for this type.
+#pod
+#pod =item coercion_export_generator( $short, $full, $undef_message )
+#pod
+#pod This is the closure that's doing coercions.
+#pod
+#pod =back
+#pod
+#pod =head2 Provided Parameters
+#pod
+#pod =over 4
+#pod
+#pod =item $short
+#pod
+#pod The short, exported name of the type.
+#pod
+#pod =item $full
+#pod
+#pod The fully qualified name of this type as L<Moose> knows it.
+#pod
+#pod =item $undef_message
+#pod
+#pod A message that will be thrown when type functionality is used but the
+#pod type does not yet exist.
+#pod
+#pod =back
+#pod
+#pod =head1 RECURSIVE SUBTYPES
+#pod
+#pod As of version 0.08, L<Moose::Types> has experimental support for Recursive
+#pod subtypes.  This will allow:
+#pod
+#pod     subtype Tree() => as HashRef[Str|Tree];
+#pod
+#pod Which validates things like:
+#pod
+#pod     {key=>'value'};
+#pod     {key=>{subkey1=>'value', subkey2=>'value'}}
+#pod
+#pod And so on.  This feature is new and there may be lurking bugs so don't be afraid
+#pod to hunt me down with patches and test cases if you have trouble.
+#pod
+#pod =head1 NOTES REGARDING TYPE UNIONS
+#pod
+#pod L<MooseX::Types> uses L<MooseX::Types::TypeDecorator> to do some overloading
+#pod which generally allows you to easily create union types:
+#pod
+#pod   subtype StrOrArrayRef,
+#pod       as Str|ArrayRef;
+#pod
+#pod As with parameterized constraints, this overloading extends to modules using the
+#pod types you define in a type library.
+#pod
+#pod   use Moose;
+#pod   use MooseX::Types::Moose qw(HashRef Int);
+#pod
+#pod   has 'attr' => ( isa => HashRef | Int );
+#pod
+#pod And everything should just work as you'd think.
+#pod
+#pod =head1 METHODS
+#pod
+#pod =head2 import
+#pod
+#pod Installs the L<MooseX::Types::Base> class into the caller and exports types
+#pod according to the specification described in L</"LIBRARY DEFINITION">. This
+#pod will continue to L<Moose::Util::TypeConstraints>' C<import> method to export
+#pod helper functions you will need to declare your types.
+#pod
+#pod =cut
 
 sub import {
     my ($class, %args) = @_;
@@ -405,13 +403,13 @@ sub import {
     1;
 }
 
-# =head2 type_export_generator
-#
-# Generate a type export, e.g. C<Int()>. This will return either a
-# L<Moose::Meta::TypeConstraint> object, or alternatively a
-# L<MooseX::Types::UndefinedType> object if the type was not yet defined.
-#
-# =cut
+#pod =head2 type_export_generator
+#pod
+#pod Generate a type export, e.g. C<Int()>. This will return either a
+#pod L<Moose::Meta::TypeConstraint> object, or alternatively a
+#pod L<MooseX::Types::UndefinedType> object if the type was not yet defined.
+#pod
+#pod =cut
 
 sub type_export_generator {
     my ($class, $type, $name) = @_;
@@ -454,12 +452,12 @@ sub type_export_generator {
     };
 }
 
-# =head2 create_arged_type_constraint ($name, @args)
-#
-# Given a String $name with @args find the matching type constraint and parameterize
-# it with @args.
-#
-# =cut
+#pod =head2 create_arged_type_constraint ($name, @args)
+#pod
+#pod Given a String $name with @args find the matching type constraint and parameterize
+#pod it with @args.
+#pod
+#pod =cut
 
 sub create_arged_type_constraint {
     my ($class, $name, @args) = @_;
@@ -478,34 +476,34 @@ sub create_arged_type_constraint {
     return $parameterized;
 }
 
-# =head2 create_base_type_constraint ($name)
-#
-# Given a String $name, find the matching type constraint.
-#
-# =cut
+#pod =head2 create_base_type_constraint ($name)
+#pod
+#pod Given a String $name, find the matching type constraint.
+#pod
+#pod =cut
 
 sub create_base_type_constraint {
     my ($class, $name) = @_;
     return find_type_constraint($name);
 }
 
-# =head2 create_type_decorator ($type_constraint)
-#
-# Given a $type_constraint, return a lightweight L<MooseX::Types::TypeDecorator>
-# instance.
-#
-# =cut
+#pod =head2 create_type_decorator ($type_constraint)
+#pod
+#pod Given a $type_constraint, return a lightweight L<MooseX::Types::TypeDecorator>
+#pod instance.
+#pod
+#pod =cut
 
 sub create_type_decorator {
     my ($class, $type_constraint) = @_;
     return MooseX::Types::TypeDecorator->new($type_constraint);
 }
 
-# =head2 coercion_export_generator
-#
-# This generates a coercion handler function, e.g. C<to_Int($value)>.
-#
-# =cut
+#pod =head2 coercion_export_generator
+#pod
+#pod This generates a coercion handler function, e.g. C<to_Int($value)>.
+#pod
+#pod =cut
 
 sub coercion_export_generator {
     my ($class, $type, $full, $undef_msg) = @_;
@@ -523,11 +521,11 @@ sub coercion_export_generator {
     }
 }
 
-# =head2 check_export_generator
-#
-# Generates a constraint check closure, e.g. C<is_Int($value)>.
-#
-# =cut
+#pod =head2 check_export_generator
+#pod
+#pod Generates a constraint check closure, e.g. C<is_Int($value)>.
+#pod
+#pod =cut
 
 sub check_export_generator {
     my ($class, $type, $full, $undef_msg) = @_;
@@ -547,18 +545,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek Dave Luehrs John Napiorkowski Justin Hunter Karen
-Etheridge Kent Fredric Matt Rolsky S Trout Paul Fenwick Rafael Kitover
-'phaylon' Tomas Florian Doran (t0m) matthewt Ragwitz Graham Knop Hans
-Dieter Pearcey Jesse
-
 =head1 NAME
 
 MooseX::Types - Organise your Moose types in libraries
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 SYNOPSIS
 
@@ -997,6 +990,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Dave Rolsky Karen Etheridge John Napiorkowski Robert 'phaylon' Sedlacek Rafael Kitover Florian Ragwitz Matt S Trout Hans Dieter Pearcey Jesse Luehrs Tomas Doran (t0m) matthewt Justin Hunter Kent Fredric Paul Fenwick Graham Knop
+
 =over 4
 
 =item *
@@ -1005,11 +1000,27 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+John Napiorkowski <jjnapiork@cpan.org>
+
+=item *
+
+Robert 'phaylon' Sedlacek <phaylon@cpan.org>
+
+=item *
+
+Rafael Kitover <rkitover@cpan.org>
+
+=item *
+
 Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Graham Knop <haarg@haarg.org>
+Matt S Trout <mst@shadowcat.co.uk>
 
 =item *
 
@@ -1021,7 +1032,11 @@ Jesse Luehrs <doy@tozt.net>
 
 =item *
 
-John Napiorkowski <jjnapiork@cpan.org>
+Tomas Doran (t0m) <bobtfish@bobtfish.net>
+
+=item *
+
+matthewt <matthewt@3efe9002-19ed-0310-8735-a98156148065>
 
 =item *
 
@@ -1029,35 +1044,15 @@ Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
 Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
-
-=item *
-
 Paul Fenwick <pjf@perltraining.com.au>
 
 =item *
 
-Rafael Kitover <rkitover@cpan.org>
-
-=item *
-
-Robert 'phaylon' Sedlacek <phaylon@cpan.org>
-
-=item *
-
-Tomas Doran (t0m) <bobtfish@bobtfish.net>
-
-=item *
-
-matthewt <matthewt@3efe9002-19ed-0310-8735-a98156148065>
+Graham Knop <haarg@haarg.org>
 
 =back
 
