@@ -1,34 +1,31 @@
 use strict;
 use warnings;
 package MooseX::Types::Combine;
-BEGIN {
-  $MooseX::Types::Combine::AUTHORITY = 'cpan:PHAYLON';
-}
 # ABSTRACT: Combine type libraries for exporting
-$MooseX::Types::Combine::VERSION = '0.44';
+$MooseX::Types::Combine::VERSION = '0.45';
 use Module::Runtime 'use_module';
-use namespace::clean;
+use namespace::autoclean;
 
-# =head1 SYNOPSIS
-#
-#     package CombinedTypeLib;
-#
-#     use base 'MooseX::Types::Combine';
-#
-#     __PACKAGE__->provide_types_from(qw/TypeLib1 TypeLib2/);
-#
-#     package UserClass;
-#
-#     use CombinedTypeLib qw/Type1 Type2 ... /;
-#
-# =head1 DESCRIPTION
-#
-# Allows you to export types from multiple type libraries.
-#
-# Libraries on the right end of the list passed to L</provide_types_from>
-# take precedence over those on the left in case of conflicts.
-#
-# =cut
+#pod =head1 SYNOPSIS
+#pod
+#pod     package CombinedTypeLib;
+#pod
+#pod     use base 'MooseX::Types::Combine';
+#pod
+#pod     __PACKAGE__->provide_types_from(qw/TypeLib1 TypeLib2/);
+#pod
+#pod     package UserClass;
+#pod
+#pod     use CombinedTypeLib qw/Type1 Type2 ... /;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Allows you to export types from multiple type libraries.
+#pod
+#pod Libraries on the right end of the list passed to L</provide_types_from>
+#pod take precedence over those on the left in case of conflicts.
+#pod
+#pod =cut
 
 sub import {
     my ($class, @types) = @_;
@@ -59,13 +56,13 @@ sub import {
         for keys %from;
 }
 
-# =head1 CLASS METHODS
-#
-# =head2 provide_types_from
-#
-# Sets or returns a list of type libraries to re-export from.
-#
-# =cut
+#pod =head1 CLASS METHODS
+#pod
+#pod =head2 provide_types_from
+#pod
+#pod Sets or returns a list of type libraries to re-export from.
+#pod
+#pod =cut
 
 sub provide_types_from {
     my ($class, @libs) = @_;
@@ -109,11 +106,11 @@ sub _provided_types {
     %$types;
 }
 
-# =head1 SEE ALSO
-#
-# L<MooseX::Types>
-#
-# =cut
+#pod =head1 SEE ALSO
+#pod
+#pod L<MooseX::Types>
+#pod
+#pod =cut
 
 1;
 
@@ -123,15 +120,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek
-
 =head1 NAME
 
 MooseX::Types::Combine - Combine type libraries for exporting
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 SYNOPSIS
 
